"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getApk = getApk;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _bluebird = require("bluebird");

var _bluebird2 = _interopRequireDefault(_bluebird);

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _wgetjs = require("wgetjs");

var _wgetjs2 = _interopRequireDefault(_wgetjs);

var wgetAsync = _bluebird2["default"].promisify(_wgetjs2["default"]);
var statAsync = _bluebird2["default"].promisify(_fs2["default"].stat);

var cacheDir = createCacheDir("apk-cache");
var apkDownloadCache = {};

function getApk(appConfig) {
  var buildUrl = appConfig.buildUrl;

  if (!apkDownloadCache[buildUrl]) {
    apkDownloadCache[buildUrl] = createDownloadPromise(appConfig);
  }

  return apkDownloadCache[buildUrl];
}

function createDownloadPromise(appConfig) {
  var apk = getFilepath(appConfig);

  return statAsync(apk).then(function (apkStat) {
    if (isApkSizeCorrect(apkStat, appConfig)) {
      return apk;
    } else {
      _fs2["default"].unlinkSync(apk);
      throw new Error("Apk file \"" + apk + "\" is invalid, deleted invalid apk file.");
    }
  })["catch"](function () {
    return downloadApk(appConfig.buildUrl, apk);
  });
}

function getFilepath(appConfig) {
  return cacheDir + "/" + appConfig.bundleIdentifier + "-" + appConfig.shortVersion + ".apk";
}

function isApkSizeCorrect(apkStat, appConfig) {
  return apkStat.size === appConfig.appSize;
}

function downloadApk(url, dest) {
  return wgetAsync({ url: url, dest: dest }).then(function (response) {
    return response.filepath;
  });
}

function createCacheDir(dirName) {
  var cacheDir = _path2["default"].resolve(dirName);
  try {
    _fs2["default"].mkdirSync(cacheDir);
  } catch (ex) {
    //ignore: dir already exists
  }

  return cacheDir;
}
//# sourceMappingURL=apkDownloader.js.map