"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = (function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; })();

exports.filterDeployableApps = filterDeployableApps;
exports.createAllAppsForDevices = createAllAppsForDevices;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _adbkit = require("adbkit");

var _adbkit2 = _interopRequireDefault(_adbkit);

var _setup = require("./../setup");

var _app = require("./app");

var _app2 = _interopRequireDefault(_app);

function filterDeployableApps(apps) {
  return _lodash2["default"].reject(apps, function (app) {
    return app.apkInstallState === _app.apkInstallState.INSTALLED;
  });
}

function createAllAppsForDevices(_ref) {
  var _ref2 = _slicedToArray(_ref, 2);

  var devices = _ref2[0];
  var appConfigs = _ref2[1];

  var createAllApps = devices.map(function (device) {
    return createAppsForDevice(device, appConfigs);
  });
  return Promise.all(createAllApps).then(_lodash2["default"].flatten);
}

function createAppsForDevice(device, appConfigs) {

  var createApps = appConfigs.map(function (appConfig) {
    return createApp(device, appConfig);
  });
  return Promise.all(createApps);
}

function createApp(device, appConfig) {
  return _setup.adb.isInstalled(device.id, appConfig.bundleIdentifier).then(function (isInstalled) {
    if (isInstalled) {
      return createAppForInstalledApp(device, appConfig);
    } else {
      return new _app2["default"](device, appConfig);
    }
  });
}

function createAppForInstalledApp(device, appConfig) {
  return getInstalledVersion(device.id, appConfig.bundleIdentifier).then(function (installedVersion) {
    return new _app2["default"](device, appConfig, installedVersion);
  });
}

function getInstalledVersion(deviceId, androidPackage) {
  var versionCodeRegex = /versionCode=(\d+)/;
  var versionNameRegex = /versionName=([\d.]*)/;
  return _setup.adb.shell(deviceId, "dumpsys package " + androidPackage).then(_adbkit2["default"].util.readAll).then(function (output) {
    return {
      versionCode: output.toString().match(versionCodeRegex)[1],
      versionName: output.toString().match(versionNameRegex)[1]
    };
  })["catch"](function (error) {
    console.log("Error " + error + " while getting version info of " + androidPackage + " from device: " + deviceId);
  });
}
//# sourceMappingURL=appCreator.js.map