"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.describeApps = describeApps;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _textTable = require("text-table");

var _textTable2 = _interopRequireDefault(_textTable);

var _app = require("./app");

var _app2 = _interopRequireDefault(_app);

var _devicePrinter = require("./../device/printer");

function describeApps(apps) {
  var appsByDeviceId = _lodash2["default"].groupBy(apps, "device.id");
  var groupedApps = _lodash2["default"].map(appsByDeviceId, function (apps) {
    return formatApps(apps);
  });
  return makeOneOutput(groupedApps);
}

function formatApps(apps) {
  var deviceDescription = (0, _devicePrinter.simpleDeviceDescription)(apps[0].device);

  var deviceHeader = _colorsSafe2["default"].underline("Deploy status for device: " + deviceDescription);
  var printableRows = apps.map(function (app) {
    return createPrintableRow(app);
  });
  return deviceHeader + "\n" + (0, _textTable2["default"])(printableRows) + "\n";
}

function makeOneOutput(stringArray) {
  var combinedLines = _lodash2["default"].reduce(stringArray, function (combinedLines, line) {
    return combinedLines + line + "\n";
  }, "");
  return combinedLines;
}

function createPrintableRow(app) {
  return [apkTitle(app), deployedVersion(app), newVersion(app), apkDownload(app)];
}

function apkTitle(app) {
  switch (app.apkInstallState) {
    case _app.apkInstallState.INSTALLED:
      return _colorsSafe2["default"].green(app.appConfig.title);
    default:
      return _colorsSafe2["default"].red(app.appConfig.title);
  }
}

function deployedVersion(app) {
  switch (app.apkInstallState) {
    case _app.apkInstallState.NOT_INSTALLED:
      return _colorsSafe2["default"].red("not deployed");

    case _app.apkInstallState.NEEDS_UPDATE:
      var versionName = _lodash2["default"].get(app.installedVersion, ["versionName"]);
      return versionName ? _colorsSafe2["default"].red(versionName) : "error";

    case _app.apkInstallState.INSTALLING:
      return _colorsSafe2["default"].grey("installing: " + app.appConfig.shortVersion);

    case _app.apkInstallState.INSTALLED:
      return _colorsSafe2["default"].green(app.appConfig.shortVersion);

    default:
      return "";
  }
}

function newVersion(app) {
  return _colorsSafe2["default"].grey(app.appConfig.shortVersion);
}

function apkDownload(app) {
  switch (app.apkDownloadState) {
    case _app.apkDownloadState.INITIAL:
      return "";
    case _app.apkDownloadState.DOWNLOADING:
      return _colorsSafe2["default"].grey("downloading " + getApkDownloadStateProgress(app));
    case _app.apkDownloadState.DOWNLOADED:
      return _colorsSafe2["default"].green("downloaded");
    default:
      return "";
  }
}

var dowloadProgressMap = {};
function getApkDownloadStateProgress(app) {
  var progress = dowloadProgressMap[app.appConfig.bundleIdentifier];
  if (!progress) {
    progress = ".";
  } else {
    progress += ".";
  }

  if (progress.includes("....")) {
    progress = "";
  }

  dowloadProgressMap[app.appConfig.bundleIdentifier] = progress;
  return progress;
}
//# sourceMappingURL=appPrinter.js.map