"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isDeviceAvailable = isDeviceAvailable;
exports.getDevices = getDevices;
exports.deviceDescription = deviceDescription;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _adbkit = require("adbkit");

var _adbkit2 = _interopRequireDefault(_adbkit);

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _printer = require("./printer");

var _setup = require("./../setup");

function isDeviceAvailable(deviceType) {
  return deviceType === "device" || deviceType === "emulator";
}

function getDevices() {
  return createDevices().then(exitOnNoDevices).then(_printer.printDevices).then(selectAvailableDevices);
}

function createDevices() {
  return _setup.adb.listDevices().then(function (devices) {
    var createDevices = devices.map(createDevice);
    return Promise.all(createDevices);
  });
}

function createDevice(_ref) {
  var id = _ref.id;
  var type = _ref.type;

  if (_setup.deviceDescriptorFile && isDeviceAvailable(type)) {
    return deviceDescription(id).then(function (deviceDescription) {
      return { id: id, type: type, description: deviceDescription };
    });
  } else {
    return Promise.resolve({ id: id, type: type });
  }
}

function deviceDescription(deviceId) {
  return adbShell(deviceId, "cat " + _setup.deviceDescriptorFile).then(trimAll)["catch"](function () {
    return "description not found";
  });
}

function adbShell(deviceId, command) {
  return _setup.adb.shell(deviceId, command).then(_adbkit2["default"].util.readAll).then(function (output) {
    return output.toString();
  });
}

function exitOnNoDevices(devices) {
  if (_lodash2["default"].isEmpty(devices)) {
    console.log(_colorsSafe2["default"].red("No devices found, Deploy Droid stops."));
    process.exit();
  }

  return devices;
}

function selectAvailableDevices(devices) {
  return _lodash2["default"].select(devices, function (device) {
    return isDeviceAvailable(device.type);
  });
}

function trimAll(string) {
  return _lodash2["default"].trim(string, " \t\r\n");
}
//# sourceMappingURL=index.js.map