"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.simpleDeviceDescription = simpleDeviceDescription;
exports.printDevices = printDevices;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _textTable = require("text-table");

var _textTable2 = _interopRequireDefault(_textTable);

var _index = require("./index");

function simpleDeviceDescription(device) {
  return deviceId(device) + " " + deviceDescription(device);
}

function printDevices(devices) {
  var header = _colorsSafe2["default"].underline("Devices found:");
  if (devicesNotAvailable(devices)) {
    header += _colorsSafe2["default"].underline.red(" ( Warning! Some devices not available )");
  }

  var printableRows = devices.map(function (device) {
    return createPrintableRow(device);
  });

  console.log(header + "\n" + (0, _textTable2["default"])(printableRows) + "\n");
  return devices;
}

function createPrintableRow(device) {
  return [deviceId(device), deviceDescription(device)];
}

function deviceId(device) {
  if ((0, _index.isDeviceAvailable)(device.type)) {
    return _colorsSafe2["default"].green(device.id);
  } else {
    return _colorsSafe2["default"].red(device.id);
  }
}

function deviceDescription(device) {
  switch (device.type) {
    case "offline":
      return _colorsSafe2["default"].red("OFFLINE - ignoring");
    case "unauthorized":
      return _colorsSafe2["default"].red("UNAUTHORIZED - ignoring");
    default:
      return device.description || "";
  }
}

function devicesNotAvailable(devices) {
  return devices.some(function (device) {
    return !(0, _index.isDeviceAvailable)(device.type);
  });
}
//# sourceMappingURL=printer.js.map