"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.simpleDeviceDescription = simpleDeviceDescription;
exports.printDevices = printDevices;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _textTable = require("text-table");

var _textTable2 = _interopRequireDefault(_textTable);

function simpleDeviceDescription(device) {
  return deviceId(device) + " " + deviceDescription(device);
}

function printDevices(devices) {
  var header = _colorsSafe2["default"].underline("Devices found:");
  if (devicesOffline(devices)) {
    header += _colorsSafe2["default"].underline.red(" ( Warning! Some devices offline )");
  }

  var printableRows = devices.map(function (device) {
    return createPrintableRow(device);
  });

  console.log(header + "\n" + (0, _textTable2["default"])(printableRows) + "\n");
  return devices;
}

function createPrintableRow(device) {
  return [deviceId(device), deviceDescription(device), deviceType(device)];
}

function deviceId(device) {
  if (device.type === "offline") {
    return _colorsSafe2["default"].red(device.id);
  } else {
    return _colorsSafe2["default"].green(device.id);
  }
}

function deviceDescription(device) {
  return device.description || "";
}

function deviceType(device) {
  if (device.type === "offline") {
    return _colorsSafe2["default"].red("OFFLINE");
  } else {
    return "";
  }
}

function devicesOffline(devices) {
  return devices.some(function (device) {
    return device.type === "offline";
  });
}
//# sourceMappingURL=devicePrinter.js.map