// jscs:disable requireCamelCaseOrUpperCaseIdentifiers
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAppConfigs = getAppConfigs;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _axios = require("axios");

var _axios2 = _interopRequireDefault(_axios);

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _appConfigPrinter = require("./appConfigPrinter");

var _setup = require("./../setup");

var APP_AVAILABLE = 2;
var STANDARD_RELEASE_TYPE = {
  alpha: 2,
  beta: 0,
  store: 1,
  enterprise: 3
};

function getAppConfigs() {
  return retrieveAllApps().then(selectDeployableApps).then(createAppConfigs).then(exitOnNoAppConfigs).then(_appConfigPrinter.printAppConfigs);
}

function retrieveAllApps() {
  return _axios2["default"].get("https://rink.hockeyapp.net/api/2/apps", {
    headers: {
      "X-HockeyAppToken": _setup.hockeyAppToken
    }
  }).then(function (response) {
    return response.data.apps;
  });
}

function selectDeployableApps(apps) {
  var filter = { platform: "Android", status: APP_AVAILABLE };

  if (_lodash2["default"].has(STANDARD_RELEASE_TYPE, _setup.releaseType)) {
    filter.release_type = STANDARD_RELEASE_TYPE[_setup.releaseType];
  } else {
    filter.custom_release_type = _setup.releaseType;
  }

  return _lodash2["default"].select(apps, filter);
}

function createAppConfigs(deployableApps) {
  var createAppConfigs = deployableApps.map(function (deployableApp) {
    return createAppConfig(deployableApp);
  });
  return Promise.all(createAppConfigs);
}

function createAppConfig(appInfo) {
  return retrieveVersion(appInfo).then(function (latestAvailableVersion) {
    return {
      title: appInfo.title,
      bundleIdentifier: appInfo.bundle_identifier,
      publicIdentifier: appInfo.public_identifier,
      shortVersion: latestAvailableVersion.shortversion,
      version: latestAvailableVersion.version,
      buildUrl: latestAvailableVersion.build_url,
      appSize: latestAvailableVersion.appsize
    };
  });
}

function retrieveVersion(appInfo) {
  var url = "https://rink.hockeyapp.net/api/2/apps/" + appInfo.public_identifier + "/app_versions";
  return _axios2["default"].get(url, {
    headers: {
      "X-HockeyAppToken": _setup.hockeyAppToken
    },
    params: {
      include_build_urls: true
    }
  }).then(function (result) {
    return getLatestAvailableVersion(result.data.app_versions);
  });
}

function getLatestAvailableVersion(appVersions) {
  var deployableVersions = _lodash2["default"].select(appVersions, { status: APP_AVAILABLE });
  return deployableVersions[0];
}

function exitOnNoAppConfigs(appConfigs) {
  if (_lodash2["default"].isEmpty(appConfigs)) {
    console.log(_colorsSafe2["default"].red("No AppConfigs found for release type: \"" + _setup.releaseType + "\", Deploy Droid stops."));
    process.exit();
  }

  return appConfigs;
}
//# sourceMappingURL=hockeyApp.js.map